@@ -1,9 +1,13 @@
 ## ----include=FALSE-------------------------------------------------------
-
-knitr::opts_chunk$set(collapse = T, comment = "#>", fig.align='center')
+knitr::opts_chunk$set(
+  collapse = TRUE,
+  comment = "#>",
+  fig.align='center',
+  dpi = 92,
+  fig.retina = 2
+)
 options(tibble.print_min = 4L, tibble.print_max = 4L)
 
-
 ## ----warning=FALSE,message=FALSE-----------------------------------------
 library(groupdata2)
 library(dplyr) # %>%
