@@ -3,7 +3,7 @@ context("splt()")
 
 test_that("dimensions of output with splt()", {
 
-  skip_test_if_old_R_version()
+  set_seed_for_R_compatibility(1)
 
   df <- data.frame("x"=c(1:12),
                    "species" = rep(c('cat','pig', 'human'), 4),
@@ -29,13 +29,16 @@ test_that("dimensions of output with splt()", {
   # Check that there are the right amount of rows in list elements
   expect_equal(get_element_sizes(df, 3), c(4,4,4))
 
+  # There should be n elements in the list
+  expect_equal(length(splt(df, 0, allow_zero = T)), 1)
+  expect_equal(nrow(splt(df, 0, allow_zero = T)[[1]]), 12)
 
 })
 
 
 test_that("splt() works with force_equal on vector", {
 
-  skip_test_if_old_R_version()
+  set_seed_for_R_compatibility(1)
 
   splt_equal <- function(data, n, method){
 
@@ -76,7 +79,7 @@ test_that("splt() works with force_equal on vector", {
 
 test_that("splt() works with force_equal on vector", {
 
-  skip_test_if_old_R_version()
+  set_seed_for_R_compatibility(1)
 
   splt_equal <- function(data, n, method, starts_col = NULL){
 
